pub enum AuthCompleteResp {
Success {
attrs: IndexMap<Handle, Signed<Attr>>,
},
PleaseRestartAuth,
}Variants
Success
All went well
Fields

attrs: IndexMap<Handle, Signed<Attr>>The resulting attributes, in the same order they were requested in
AuthStartReq::attr_types or AuthStartReq::attr_type_choices.
In the latter case, the key indicates the choice the user made.
PleaseRestartAuth
Something went wrong; please start again at AuthStartEP.
One reason is that the authentication server restarted and that the provided authenication state is no longer valid.