pub enum AuthStartResp {
Success {
task: AuthTask,
state: AuthState,
},
UnknownAttrType(Handle),
SourceNotAvailableFor(Handle),
Conflict(Handle, Handle),
ChainedSessionsTemporarilyUnavailable,
}Expand description
Response to AuthStartEP
Variants
Success
Authentication process was started
Fields
task: AuthTaskTask for the global client to satisfy the authentication server. Depends on the requested attribute types
state: AuthStateOpaque state that should be sent with the AuthCompleteReq.
UnknownAttrType(Handle)
No attribute type known with this handle
SourceNotAvailableFor(Handle)
The AuthStartReq::source is not available for the attribute type with this handle
Conflict(Handle, Handle)
For some reason these two attribute types cannot be requested together
For attr::Source::Yivi this might happen if the two attribute types can be derived from
the same crate::servers::yivi::AttributeTypeIdentifier. This is not something that is currently e
expected to happen.
The authentication server is temporarily at its configured maximum number of concurrent chained sessions, so it cannot start a new one right now.
The global client may fall back to the non-chained flow by retrying AuthStartEP with
yivi_chained_session (and yivi_chained_session_drip) set to false, at the cost of the
user scanning a second Yivi QR for card issuance.