pub enum CardResp {
Success {
attr: Signed<Attr>,
issuance_request: JWT,
yivi_requestor_url: Url,
},
PleaseRetryWithNewCardPseud,
}Expand description
What’s returned by CardEP
Variants
Success
Fields

attr: Signed<Attr>Attribute for the card that can be added to the user’s account via the
phc::user::EnterEP endpoint.
Make sure that you first add this attribute to the user’s account before you add the card to the user’s yivi app - we do not want to end up with a card in the yivi app that is not connected to the user’s account.

issuance_request: JWTSigned issuance request to issue the pubhubs card. Can be used to start a new session
with the Yivi server directly, or an already existing chained session with the
authentication server, via YiviReleaseNextSessionEP.
Before making the issuance request, make sure CardResp::Success::attr is added to the
user’s account!
PleaseRetryWithNewCardPseud
Please try again with a new signed card pseudonym package