pub enum YiviWaitForResultResp {
Success {
disclosure: JWT,
},
PleaseRestartAuth,
SessionGone,
}Expand description
What’s returned by YiviWaitForResultEP
Variants
Success
PleaseRestartAuth
Something went wrong; please start again at AuthStartEP.
One reason is that the authentication server restarted and that the provided authenication state is no longer valid.
SessionGone
The request seems fine, but the session cannot be found. Either the session expired, or was already completed. Could caused by a logic error in the client, but also by a slow internet connection.