pub struct AttrKeyResp {
pub latest_key: (B64UU, NumericDate),
pub old_key: Option<B64UU>,
}Expand description
Part of a successful AttrKeyResp.
Fields
latest_key: (B64UU, NumericDate)A pair, (key, timestamp), where key is the latest attribute key for the requested attribute
and timestamp can be used to retrieve the same key again later on by setting AttrKeyReq::timestamp.
old_key: Option<B64UU>The attribute key at AttrKeyReq::timestamp, when this was set.
This key should only be use for decryption, not for encryption.