AttrKeysEP

Struct AttrKeysEP 

pub struct AttrKeysEP {}
Allows the global client to retrieve secrets tied to identifying Attributes.

These attribute keys are used by the global client to encrypt its master secret(s) before storing them at pubhubs central.

To allow a compromised attribute key to be replaced (automatically), attribute keys are tied not only to an attribute, but also a timestamp.