pub struct CardEP {}Expand description
Request a pubhubs card, or rather, a signed session request for the issuance of a pubhubs card that can be passed to the authentication server’s yivi server to actually issue the card.