pub struct CardReq {
pub card_pseud_package: Signed<CardPseudPackage>,
pub comment: Option<String>,
}Expand description
Request type for CardEP
Fields
card_pseud_package: Signed<CardPseudPackage>A by PHC signed registration pseudonym obtained via phc::user::CardPseudEP.
comment: Option<String>Optional comment used after the registration date field. Could perhaps be the partly anonymized email address and phone number used to originally register this account.