pub struct YiviWaitForResultEP {}Expand description
Wait for the disclosure result that the yivi server will post to the authentication server
Might return ErrorCode::BadRequest when yivi is not configured for this authentication
server, or when AuthStartReq::yivi_chained_session was not set for YiviWaitForResultReq::state.