pub enum AuthStartResp {
Success {
task: AuthTask,
state: AuthState,
},
UnknownAttrType(Handle),
SourceNotAvailableFor(Handle),
Conflict(Handle, Handle),
}Expand description
Response to AuthStartEP
Variants
Success
Authentication process was started
Fields

task: AuthTaskTask for the global client to satisfy the authentication server. Depends on the requested attribute types

state: AuthStateOpaque state that should be sent with the AuthCompleteReq.
UnknownAttrType(Handle)
No attribute type known with this handle
SourceNotAvailableFor(Handle)
The AuthStartReq::source is not available for the attribute type with this handle
Conflict(Handle, Handle)
For some reason these two attribute types cannot be requested together
For attr::Source::Yivi this might happen if the two attribute types can be derived from
the same crate::servers::yivi::AttributeTypeIdentifier. This is not something that is currently e
expected to happen.