pub enum YiviReleaseNextSessionResp {
Success {},
PleaseRestartAuth,
SessionGone,
YiviServerGone,
TooEarly,
}Expand description
What’s returned by YiviReleaseNextSessionEP
Variants
Success
PleaseRestartAuth
Something went wrong; please start again at AuthStartEP.
One reason is that the authentication server restarted and that the provided authenication state is no longer valid.
SessionGone
The request seems fine, but the session cannot be found. Either the session expired, or was already completed. Could caused by a logic error in the client, but also by a slow internet connection.
YiviServerGone
The request seems fine, but the Yivi server is gone, perhaps because it timed out.
Also returned when the authentication server deems the yivi server stale, see YiviReleaseNextSessionReq::stale_after.
TooEarly
Trying to release a yivi server that’s not there yet. You should first call the
YiviWaitForResultEP endpoint to make sure the yivi server is there.