pub struct YiviReleaseNextSessionReq {
pub state: AuthState,
pub next_session: Option<JWT>,
pub stale_after: Option<u16>,
}Expand description
Request type for YiviReleaseNextSessionEP
Fields
state: AuthStateThe AuthStartResp::Success::state returned earlier
next_session: Option<JWT>Instructs the authentication server on what next session (if any) to start at the yivi server.
If None the yivi server will be served a HTTP 204 causing it to stop the yivi flow
normally without opening a follow-up session.
Otherwise it must be some signed session request that will be passed to yivi server.
This session request must be signed by the authentication server’s yivi requestor credentials,
for example, CardResp::Success::issuance_request.
The value None is not permitted when AuthStartReq::yivi_chained_session_drip
was set (because in that case the HTTP status code 200 has already been sent to the Yivi server.)
If None is submitted anyway, this causes an ErrorCode::BadRequest.
stale_after: Option<u16>If the yivi server has been waiting more than this amount of milliseconds when it is about to be released, dont release it, but ghost it. The reason is that drip mechanism may be too slow to detect the yivi server timing out.